#ifndef __PICTURE_HPP
#define __PICTURE_HPP

#ifndef _WINDOWS_
	#include <windows.h>
#endif

#ifndef __ERROR_HPP
	#include "error.hpp"
#endif

//____________________________________________________________________________
//
//	Abstract base class for objects which actually do all the image loading
// and drawing.  
//
//	Derived classes are expected to:
//		1) Provide constructor, destructor, and override Draw().
//		2) Maintain the correct value in mnStatus at all times.  This should
//			be xeSUCCESS whenever the picture object is in a valid state.
//			Derived classes inherit the status() and isOK() functions with no
//			other work.
//____________________________________________________________________________
class XPictureBase
{
  protected:
	XeStatus			mnStatus;

  public:
	XPictureBase();
	virtual ~XPictureBase();

	XeStatus  			status() const;
	BOOL 				isOK() const;

	// Pure virtuals
	virtual short 		height() const = 0;
	virtual short 		width() const = 0;
	virtual XeStatus	draw(	CDC & destDC, 
								const RECT &destRect) = 0;
};


#endif // __PICTURE_HPP
